@@ -34,6 +34,7 @@
 #include <string.h>
 
 typedef struct _EggAsn1xDef ASN1_ARRAY_TYPE;
+typedef struct _EggAsn1xDef asn1_static_node;
 #include "test.asn.h"
 
 const gchar I33[] =           "\x02\x01\x2A";
@@ -573,7 +574,8 @@ test_generalized_time (void)
 	asn = egg_asn1x_create (test_asn1_tab, "TestGeneralized");
 	g_assert (asn);
 
-	g_assert_cmpint (EGG_ASN1X_TIME, ==, egg_asn1x_type (asn));
+	if (EGG_ASN1X_TIME != egg_asn1x_type (asn))
+		g_assert_cmpint (EGG_ASN1X_GENERALIZED_TIME, ==, egg_asn1x_type (asn));
 
 	/* Shouldn't succeed */
 	value = egg_asn1x_get_time_as_long (asn);
