@@ -210,7 +210,9 @@ test_reload (Test *test, gconstpointer unused)
 int
 main (int argc, char **argv)
 {
+#if !GLIB_CHECK_VERSION(2,35,0)
 	g_type_init ();
+#endif
 	g_test_init (&argc, &argv, NULL);
 	g_set_prgname ("test-gnupg-collection");
 
